AsNullTermStr

Trait AsNullTermStr 

pub trait AsNullTermStr {
    // Required method
    fn as_null_term_str(&self) -> &MeasuredNullTermStr;
}
Allow NullTermString instances to be interpreted as references to MeasuredNullTermStr.

Required Methods

fn as_null_term_str(&self) -> &MeasuredNullTermStr

Similar to AsRef or Borrow.

This is necessary because those traits require the use of DSTs (dynamically-sized types) and cannot be made to work with tagged lifetimes like we use in this module.

Implementors